aboutsummaryrefslogtreecommitdiff
path: root/src/jtag
diff options
context:
space:
mode:
authorAntonio Borneo <borneo.antonio@gmail.com>2019-08-23 15:12:57 +0200
committerOleksij Rempel <linux@rempel-privat.de>2020-01-29 05:36:30 +0000
commit291d1511aab3eee6a181510e1b1ff9282d47e69c (patch)
tree69c960db8bedb8d0ce33984b2b08419fe5918498 /src/jtag
parent70babcc00b5f495e4d0dbac9bad88d78592d2779 (diff)
openocd: fix minor inconsistencies after renaming "adapter" command
Replace in the code any reference to the deprecated commands. Change-Id: I75d28064017d664990b4024967900f32e196230a Signed-off-by: Antonio Borneo <borneo.antonio@gmail.com> Reviewed-on: http://openocd.zylin.com/5282 Tested-by: jenkins Reviewed-by: Marc Schink <dev@zapb.de> Reviewed-by: Oleksij Rempel <linux@rempel-privat.de>
Diffstat (limited to 'src/jtag')
-rw-r--r--src/jtag/core.c6
-rw-r--r--src/jtag/drivers/cmsis_dap_usb.c4
2 files changed, 5 insertions, 5 deletions
diff --git a/src/jtag/drivers/cmsis_dap_usb.c b/src/jtag/drivers/cmsis_dap_usb.c
index c0728214..3d2693c0 100644
--- a/src/jtag/drivers/cmsis_dap_usb.c
+++ b/src/jtag/drivers/cmsis_dap_usb.c
@@ -1628,10 +1628,10 @@ static int cmsis_dap_execute_queue(void)
static int cmsis_dap_speed(int speed)
{
if (speed > DAP_MAX_CLOCK)
- LOG_INFO("High speed (adapter_khz %d) may be limited by adapter firmware.", speed);
+ LOG_INFO("High speed (adapter speed %d) may be limited by adapter firmware.", speed);
if (speed == 0) {
- LOG_ERROR("RTCK not supported. Set nonzero adapter_khz.");
+ LOG_ERROR("RTCK not supported. Set nonzero \"adapter speed\".");
return ERROR_JTAG_NOT_IMPLEMENTED;
}
diff --git a/src/jtag/core.c b/src/jtag/core.c
index 111b122d..24d645a4 100644
--- a/src/jtag/core.c
+++ b/src/jtag/core.c
@@ -1519,9 +1519,9 @@ int adapter_init(struct command_context *cmd_ctx)
return ERROR_OK;
if (!adapter_driver) {
/* nothing was previously specified by "interface" command */
LOG_ERROR("Debug Adapter has to be specified, "
- "see \"interface\" command");
+ "see \"adapter driver\" command");
return ERROR_JTAG_INVALID_INTERFACE;
}
@@ -1538,7 +1538,7 @@ int adapter_init(struct command_context *cmd_ctx)
if (CLOCK_MODE_UNSELECTED == clock_mode) {
LOG_ERROR("An adapter speed is not selected in the init script."
- " Insert a call to adapter_khz or jtag_rclk to proceed.");
+ " Insert a call to \"adapter speed\" or \"jtag_rclk\" to proceed.");
return ERROR_JTAG_INIT_FAILED;
}
@@ -1519,9 +1519,9 @@ int adapter_init(struct command_context *cmd_ctx)
return ERROR_OK;
if (!adapter_driver) {
- /* nothing was previously specified by "interface" command */
+ /* nothing was previously specified by "adapter driver" command */
LOG_ERROR("Debug Adapter has to be specified, "